@@ -74,14 +74,15 @@ function startAppForMount(app, mount) {
 
 /******************************************/
 
-const HotplugSnifferIface = '<node> \
-<interface name="org.gnome.Shell.HotplugSniffer"> \
-<method name="SniffURI"> \
-    <arg type="s" direction="in" /> \
-    <arg type="as" direction="out" /> \
-</method> \
-</interface> \
-</node>';
+const HotplugSnifferIface = `
+<node>
+<interface name="org.gnome.Shell.HotplugSniffer">
+<method name="SniffURI">
+    <arg type="s" direction="in" />
+    <arg type="as" direction="out" />
+</method>
+</interface>
+</node>`;
 
 const HotplugSnifferProxy = Gio.DBusProxy.makeProxyWrapper(HotplugSnifferIface);
 function HotplugSniffer() {
@@ -93,26 +94,25 @@ function HotplugSniffer() {
 var ContentTypeDiscoverer = new Lang.Class({
     Name: 'ContentTypeDiscoverer',
 
-    _init: function(callback) {
+    _init(callback) {
         this._callback = callback;
         this._settings = new Gio.Settings({ schema_id: SETTINGS_SCHEMA });
     },
 
-    guessContentTypes: function(mount) {
+    guessContentTypes(mount) {
         let autorunEnabled = !this._settings.get_boolean(SETTING_DISABLE_AUTORUN);
         let shouldScan = autorunEnabled && !isMountNonLocal(mount);
 
         if (shouldScan) {
             // guess mount's content types using GIO
             mount.guess_content_type(false, null,
-                                     Lang.bind(this,
-                                               this._onContentTypeGuessed));
+                                     this._onContentTypeGuessed.bind(this));
         } else {
             this._emitCallback(mount, []);
         }
     },
 
-    _onContentTypeGuessed: function(mount, res) {
+    _onContentTypeGuessed(mount, res) {
         let contentTypes = [];
 
         try {
@@ -129,23 +129,23 @@ var ContentTypeDiscoverer = new Lang.Class({
 
             let hotplugSniffer = new HotplugSniffer();
             hotplugSniffer.SniffURIRemote(root.get_uri(),
-                 Lang.bind(this, function([contentTypes]) {
+                 ([contentTypes]) => {
                      this._emitCallback(mount, contentTypes);
-                 }));
+                 });
         }
     },
 
-    _emitCallback: function(mount, contentTypes) {
+    _emitCallback(mount, contentTypes) {
         if (!contentTypes)
             contentTypes = [];
 
         // we're not interested in win32 software content types here
-        contentTypes = contentTypes.filter(function(type) {
-            return (type != 'x-content/win32-software');
-        });
+        contentTypes = contentTypes.filter(
+            type => (type != 'x-content/win32-software')
+        );
 
         let apps = [];
-        contentTypes.forEach(function(type) {
+        contentTypes.forEach(type => {
             let app = Gio.app_info_get_default_for_type(type, false);
 
             if (app)
@@ -162,36 +162,36 @@ var ContentTypeDiscoverer = new Lang.Class({
 var AutorunManager = new Lang.Class({
     Name: 'AutorunManager',
 
-    _init: function() {
+    _init() {
         this._session = new GnomeSession.SessionManager();
         this._volumeMonitor = Gio.VolumeMonitor.get();
 
         this._dispatcher = new AutorunDispatcher(this);
     },
 
-    enable: function() {
-        this._mountAddedId = this._volumeMonitor.connect('mount-added', Lang.bind(this, this._onMountAdded));
-        this._mountRemovedId = this._volumeMonitor.connect('mount-removed', Lang.bind(this, this._onMountRemoved));
+    enable() {
+        this._mountAddedId = this._volumeMonitor.connect('mount-added', this._onMountAdded.bind(this));
+        this._mountRemovedId = this._volumeMonitor.connect('mount-removed', this._onMountRemoved.bind(this));
     },
 
-    disable: function() {
+    disable() {
         this._volumeMonitor.disconnect(this._mountAddedId);
         this._volumeMonitor.disconnect(this._mountRemovedId);
     },
 
-    _onMountAdded: function(monitor, mount) {
+    _onMountAdded(monitor, mount) {
         // don't do anything if our session is not the currently
         // active one
         if (!this._session.SessionIsActive)
             return;
 
-        let discoverer = new ContentTypeDiscoverer(Lang.bind(this, function(mount, apps, contentTypes) {
+        let discoverer = new ContentTypeDiscoverer((mount, apps, contentTypes) => {
             this._dispatcher.addMount(mount, apps, contentTypes);
-        }));
+        });
         discoverer.guessContentTypes(mount);
     },
 
-    _onMountRemoved: function(monitor, mount) {
+    _onMountRemoved(monitor, mount) {
         this._dispatcher.removeMount(mount);
     }
 });
@@ -199,13 +199,13 @@ var AutorunManager = new Lang.Class({
 var AutorunDispatcher = new Lang.Class({
     Name: 'AutorunDispatcher',
 
-    _init: function(manager) {
+    _init(manager) {
         this._manager = manager;
         this._sources = [];
         this._settings = new Gio.Settings({ schema_id: SETTINGS_SCHEMA });
     },
 
-    _getAutorunSettingForType: function(contentType) {
+    _getAutorunSettingForType(contentType) {
         let runApp = this._settings.get_strv(SETTING_START_APP);
         if (runApp.indexOf(contentType) != -1)
             return AutorunSetting.RUN;
@@ -221,11 +221,8 @@ var AutorunDispatcher = new Lang.Class({
         return AutorunSetting.ASK;
     },
 
-    _getSourceForMount: function(mount) {
-        let filtered =
-            this._sources.filter(function (source) {
-                return (source.mount == mount);
-            });
+    _getSourceForMount(mount) {
+        let filtered = this._sources.filter(source => (source.mount == mount));
 
         // we always make sure not to add two sources for the same
         // mount in addMount(), so it's safe to assume filtered.length
@@ -236,7 +233,7 @@ var AutorunDispatcher = new Lang.Class({
         return null;
     },
 
-    _addSource: function(mount, apps) {
+    _addSource(mount, apps) {
         // if we already have a source showing for this 
         // mount, return
         if (this._getSourceForMount(mount))
@@ -246,7 +243,7 @@ var AutorunDispatcher = new Lang.Class({
         this._sources.push(new AutorunSource(this._manager, mount, apps));
     },
 
-    addMount: function(mount, apps, contentTypes) {
+    addMount(mount, apps, contentTypes) {
         // if autorun is disabled globally, return
         if (this._settings.get_boolean(SETTING_DISABLE_AUTORUN))
             return;
@@ -284,7 +281,7 @@ var AutorunDispatcher = new Lang.Class({
             this._addSource(mount, apps);
     },
 
-    removeMount: function(mount) {
+    removeMount(mount) {
         let source = this._getSourceForMount(mount);
         
         // if we aren't tracking this mount, don't do anything
@@ -300,7 +297,7 @@ var AutorunSource = new Lang.Class({
     Name: 'AutorunSource',
     Extends: MessageTray.Source,
 
-    _init: function(manager, mount, apps) {
+    _init(manager, mount, apps) {
         this._manager = manager;
         this.mount = mount;
         this.apps = apps;
@@ -314,11 +311,11 @@ var AutorunSource = new Lang.Class({
         this.notify(this._notification);
     },
 
-    getIcon: function() {
+    getIcon() {
         return this.mount.get_icon();
     },
 
-    _createPolicy: function() {
+    _createPolicy() {
         return new MessageTray.NotificationApplicationPolicy('org.gnome.Nautilus');
     }
 });
@@ -327,27 +324,27 @@ var AutorunNotification = new Lang.Class({
     Name: 'AutorunNotification',
     Extends: MessageTray.Notification,
 
-    _init: function(manager, source) {
+    _init(manager, source) {
         this.parent(source, source.title);
 
         this._manager = manager;
         this._mount = source.mount;
     },
 
-    createBanner: function() {
+    createBanner() {
         let banner = new MessageTray.NotificationBanner(this);
 
-        this.source.apps.forEach(Lang.bind(this, function (app) {
+        this.source.apps.forEach(app => {
             let actor = this._buttonForApp(app);
 
             if (actor)
                 banner.addButton(actor);
-        }));
+        });
 
         return banner;
     },
 
-    _buttonForApp: function(app) {
+    _buttonForApp(app) {
         let box = new St.BoxLayout();
         let icon = new St.Icon({ gicon: app.get_icon(),
                                  style_class: 'hotplug-notification-item-icon' });
@@ -366,15 +363,15 @@ var AutorunNotification = new Lang.Class({
                                      button_mask: St.ButtonMask.ONE,
                                      style_class: 'hotplug-notification-item button' });
 
-        button.connect('clicked', Lang.bind(this, function() {
+        button.connect('clicked', () => {
             startAppForMount(app, this._mount);
             this.destroy();
-        }));
+        });
 
         return button;
     },
 
-    activate: function() {
+    activate() {
         this.parent();
 
         let app = Gio.app_info_get_default_for_type('inode/directory', false);
