@@ -125,16 +125,6 @@ var _Draggable = new Lang.Class({
     },
 
     _onTouchEvent(actor, event) {
-        // Here we only handle touch events on wayland. On X11
-        // we do get emulated pointer events, which already works
-        // for single-touch cases. Besides, the X11 passive touch grab
-        // set up by Mutter will make us see first the touch events
-        // and later the pointer events, so it will look like two
-        // unrelated series of events, we want to avoid double handling
-        // in these cases.
-        if (!Meta.is_wayland_compositor())
-            return Clutter.EVENT_PROPAGATE;
-
         if (event.type() != Clutter.EventType.TOUCH_BEGIN ||
             !global.display.is_pointer_emulating_sequence(event.get_event_sequence()))
             return Clutter.EVENT_PROPAGATE;
@@ -290,7 +280,7 @@ var _Draggable = new Lang.Class({
 
         this._touchSequence = sequence;
         this._grabEvents();
-        global.screen.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
 
         this._dragX = this._dragStartX = stageX;
         this._dragY = this._dragStartY = stageY;
@@ -406,15 +396,10 @@ var _Draggable = new Lang.Class({
         return true;
     },
 
-    _pickTargetActor() {
-        return this._dragActor.get_stage().get_actor_at_pos(Clutter.PickMode.ALL,
-                                                            this._dragX, this._dragY);
-    },
-
     _updateDragHover() {
         this._updateHoverId = 0;
-        let target = this._pickTargetActor();
-
+        let target = this._dragActor.get_stage().get_actor_at_pos(Clutter.PickMode.ALL,
+                                                                  this._dragX, this._dragY);
         let dragEvent = {
             x: this._dragX,
             y: this._dragY,
@@ -422,29 +407,16 @@ var _Draggable = new Lang.Class({
             source: this.actor._delegate,
             targetActor: target
         };
-
-        let targetActorDestroyHandlerId;
-        let handleTargetActorDestroyClosure;
-        handleTargetActorDestroyClosure = () => {
-            target = this._pickTargetActor();
-            dragEvent.targetActor = target;
-            targetActorDestroyHandlerId =
-                target.connect('destroy', handleTargetActorDestroyClosure);
-        };
-        targetActorDestroyHandlerId =
-            target.connect('destroy', handleTargetActorDestroyClosure);
-
         for (let i = 0; i < dragMonitors.length; i++) {
             let motionFunc = dragMonitors[i].dragMotion;
             if (motionFunc) {
                 let result = motionFunc(dragEvent);
                 if (result != DragMotionResult.CONTINUE) {
-                    global.screen.set_cursor(DRAG_CURSOR_MAP[result]);
+                    global.display.set_cursor(DRAG_CURSOR_MAP[result]);
                     return GLib.SOURCE_REMOVE;
                 }
             }
         }
-        dragEvent.targetActor.disconnect(targetActorDestroyHandlerId);
 
         while (target) {
             if (target._delegate && target._delegate.handleDragOver) {
@@ -458,13 +430,13 @@ var _Draggable = new Lang.Class({
                                                              targY,
                                                              0);
                 if (result != DragMotionResult.CONTINUE) {
-                    global.screen.set_cursor(DRAG_CURSOR_MAP[result]);
+                    global.display.set_cursor(DRAG_CURSOR_MAP[result]);
                     return GLib.SOURCE_REMOVE;
                 }
             }
             target = target.get_parent();
         }
-        global.screen.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
         return GLib.SOURCE_REMOVE;
     },
 
@@ -537,7 +509,7 @@ var _Draggable = new Lang.Class({
                     }
 
                     this._dragInProgress = false;
-                    global.screen.set_cursor(Meta.Cursor.DEFAULT);
+                    global.display.set_cursor(Meta.Cursor.DEFAULT);
                     this.emit('drag-end', event.get_time(), true);
                     this._dragComplete();
                     return true;
@@ -589,7 +561,7 @@ var _Draggable = new Lang.Class({
         let [snapBackX, snapBackY, snapBackScale] = this._getRestoreLocation();
 
         if (this._actorDestroyed) {
-            global.screen.set_cursor(Meta.Cursor.DEFAULT);
+            global.display.set_cursor(Meta.Cursor.DEFAULT);
             if (!this._buttonDown)
                 this._dragComplete();
             this.emit('drag-end', eventTime, false);
@@ -648,7 +620,7 @@ var _Draggable = new Lang.Class({
         if (!this._buttonDown)
             this._dragComplete();
 
-        global.screen.set_cursor(Meta.Cursor.DEFAULT);
+        global.display.set_cursor(Meta.Cursor.DEFAULT);
     },
 
     _onAnimationComplete(dragActor, eventTime) {
