@@ -307,8 +307,11 @@ var AppMenuButton = new Lang.Class({
             }
         }
 
+        let shellShowsAppMenu = this._gtkSettings.gtk_shell_shows_app_menu;
+        Meta.prefs_set_show_fallback_app_menu(!shellShowsAppMenu);
+
         let visible = (this._targetApp != null &&
-                       this._gtkSettings.gtk_shell_shows_app_menu &&
+                       shellShowsAppMenu &&
                        !Main.overview.visibleTarget);
         if (visible)
             this.show();
@@ -776,6 +779,7 @@ var Panel = new Lang.Class({
         this.actor = new Shell.GenericContainer({ name: 'panel',
                                                   reactive: true });
         this.actor._delegate = this;
+        this.actor.set_offscreen_redirect(Clutter.OffscreenRedirect.ALWAYS);
 
         this._sessionStyle = null;
 
