@@ -551,15 +551,46 @@ void
 shell_app_open_new_window (ShellApp      *app,
                            int            workspace)
 {
+  GActionGroup *group = NULL;
+  const char * const *actions;
+
   g_return_if_fail (app->info != NULL);
 
-  /* Here we just always launch the application again, even if we know
+  /* First check whether the application provides a "new-window" desktop
+   * action - it is a safe bet that it will open a new window, and activating
+   * it will trigger startup notification if necessary
+   */
+  actions = g_desktop_app_info_list_actions (G_DESKTOP_APP_INFO (app->info));
+
+  if (g_strv_contains (actions, "new-window"))
+    {
+      shell_app_launch_action (app, "new-window", 0, workspace);
+      return;
+    }
+
+  /* Next, check whether the app exports an explicit "new-window" action
+   * that we can activate on the bus - the muxer will add startup notification
+   * information to the platform data, so this should work just as well as
+   * desktop actions.
+   */
+  group = app->running_state ? G_ACTION_GROUP (app->running_state->muxer)
+                             : NULL;
+
+  if (group &&
+      g_action_group_has_action (group, "app.new-window") &&
+      g_action_group_get_action_parameter_type (group, "app.new-window") == NULL)
+    {
+      g_action_group_activate_action (group, "app.new-window", NULL);
+
+      return;
+    }
+
+  /* Lastly, just always launch the application again, even if we know
    * it was already running.  For most applications this
    * should have the effect of creating a new window, whether that's
    * a second process (in the case of Calculator) or IPC to existing
    * instance (Firefox).  There are a few less-sensical cases such
-   * as say Pidgin.  Ideally, we have the application express to us
-   * that it supports an explicit new-window action.
+   * as say Pidgin.
    */
   shell_app_launch (app, 0, workspace, FALSE, NULL);
 }
@@ -586,10 +617,7 @@ shell_app_can_open_new_window (ShellApp *app)
   state = app->running_state;
 
   /* If the app has an explicit new-window action, then it can
-
-     (or it should be able to - we don't actually call the action
-     because we need to trigger startup notification, so it still
-     depends on what the app decides to do for Activate vs ActivateAction)
+     (or it should be able to) ...
   */
   if (g_action_group_has_action (G_ACTION_GROUP (state->muxer), "app.new-window"))
     return TRUE;
@@ -1179,7 +1207,7 @@ shell_app_request_quit (ShellApp   *app)
   return TRUE;
 }
 
-#ifdef HAVE_SYSTEMD
+#if !defined(HAVE_GIO_DESKTOP_LAUNCH_URIS_WITH_FDS) && defined(HAVE_SYSTEMD)
 /* This sets up the launched application to log to the journal
  * using its own identifier, instead of just "gnome-session".
  */
@@ -1227,6 +1255,7 @@ shell_app_launch (ShellApp     *app,
   ShellGlobal *global;
   GAppLaunchContext *context;
   gboolean ret;
+  GSpawnFlags flags;
 
   if (app->info == NULL)
     {
@@ -1246,9 +1275,39 @@ shell_app_launch (ShellApp     *app,
   if (discrete_gpu)
     g_app_launch_context_setenv (context, "DRI_PRIME", "1");
 
+  /* Set LEAVE_DESCRIPTORS_OPEN in order to use an optimized gspawn
+   * codepath. The shell's open file descriptors should be marked CLOEXEC
+   * so that they are automatically closed even with this flag set.
+   */
+  flags = G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD |
+          G_SPAWN_LEAVE_DESCRIPTORS_OPEN;
+
+#ifdef HAVE_GIO_DESKTOP_LAUNCH_URIS_WITH_FDS
+  /* Optimized spawn path, avoiding a child_setup function */
+  {
+    int journalfd = -1;
+
+#ifdef HAVE_SYSTEMD
+    journalfd = sd_journal_stream_fd (shell_app_get_id (app), LOG_INFO, FALSE);
+#endif /* HAVE_SYSTEMD */
+
+    ret = g_desktop_app_info_launch_uris_as_manager_with_fds (app->info, NULL,
+                                                              context,
+                                                              flags,
+                                                              NULL, NULL,
+                                                              wait_pid, NULL,
+                                                              -1,
+                                                              journalfd,
+                                                              journalfd,
+                                                              error);
+
+    if (journalfd >= 0)
+      (void) close (journalfd);
+  }
+#else /* !HAVE_GIO_DESKTOP_LAUNCH_URIS_WITH_FDS */
   ret = g_desktop_app_info_launch_uris_as_manager (app->info, NULL,
                                                    context,
-                                                   G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+                                                   flags,
 #ifdef HAVE_SYSTEMD
                                                    app_child_setup, (gpointer)shell_app_get_id (app),
 #else
@@ -1256,6 +1315,7 @@ shell_app_launch (ShellApp     *app,
 #endif
                                                    wait_pid, NULL,
                                                    error);
+#endif /* HAVE_GIO_DESKTOP_LAUNCH_URIS_WITH_FDS */
   g_object_unref (context);
 
   return ret;
